@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-10 14:40:50
-# @Last Modified time: 2022-08-08 18:54:02
+# @Last Modified time: 2022-08-11 10:05:30
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -11,7 +11,7 @@
 import threading
 import psycopg2
 
-from pydbapi.db import DBCommon, DBFileExec
+from pydbapi.db import DBMixin, DBFileExec
 from pydbapi.sql import SqlCompile
 from pydbapi.conf import REDSHIFT_AUTO_RULES
 
@@ -42,7 +42,7 @@ class SqlRedshiftCompile(SqlCompile):
         return sql
 
 
-class RedshiftDB(DBCommon, DBFileExec):
+class RedshiftDB(DBMixin, DBFileExec):
     _instance_lock = threading.Lock()
 
     def __init__(self, host, user, password, database, port='5439', safe_rule=True):
